==> v0.13.11.tar.gz: git-next/crates/core/src/config/server_repo_config.rs <==
//
use std::path::PathBuf;

use crate::config::{
    git_dir::StoragePathType, BranchName, GitDir, RepoBranches, RepoConfig, RepoConfigSource,
    RepoPath,
};

/// Defines a Repo within a `ForgeConfig` to be monitored by the server
/// Maps from `git-next-server.toml` at `forge.{forge}.repos.{name}`
#[derive(
    Clone,
    Debug,
    derive_more::From,
    PartialEq,
    Eq,
    PartialOrd,
    Ord,
    serde::Deserialize,
    derive_more::Display,
    derive_more::Constructor,
)]
#[display("{}@{}", repo, branch)]
pub struct ServerRepoConfig {
    repo: String,
    branch: String,
    gitdir: Option<PathBuf>,
    main: Option<String>,
    next: Option<String>,
    dev: Option<String>,
}
impl ServerRepoConfig {
    pub(crate) fn repo(&self) -> RepoPath {
        RepoPath::new(self.repo.clone())
    }

    pub(crate) fn branch(&self) -> BranchName {
        BranchName::new(&self.branch)
    }

    #[must_use]
    pub fn gitdir(&self) -> Option<GitDir> {
        self.gitdir
            .clone()
            // Provenance is external as the gitdir is only used to specify non-internal paths
            .map(|dir| GitDir::new(dir, StoragePathType::External))
    }

    /// Returns a `RepoConfig` from the server configuration if ALL THREE branches were provided
    #[must_use]
    pub fn repo_config(&self) -> Option<RepoConfig> {
        match (&self.main, &self.next, &self.dev) {
            (Some(main), Some(next), Some(dev)) => Some(RepoConfig::new(
                RepoBranches::new(main.to_string(), next.to_string(), dev.to_string()),
                RepoConfigSource::Server,
            )),
            _ => None,
        }
    }
}

==> v0.14.1.tar.gz: git-next/crates/core/src/config/server_repo_config.rs <==
//
use std::path::PathBuf;

use crate::{
    config::{
        git_dir::StoragePathType, BranchName, GitDir, RepoBranches, RepoConfig, RepoConfigSource,
        RepoPath,
    },
    s,
};

/// Defines a Repo within a `ForgeConfig` to be monitored by the server
/// Maps from `git-next-server.toml` at `forge.{forge}.repos.{name}`
#[derive(
    Clone,
    Debug,
    derive_more::From,
    PartialEq,
    Eq,
    PartialOrd,
    Ord,
    serde::Deserialize,
    derive_more::Display,
    derive_more::Constructor,
)]
#[display("{}@{}", repo, branch)]
pub struct ServerRepoConfig {
    repo: String,
    branch: String,
    gitdir: Option<PathBuf>,
    main: Option<String>,
    next: Option<String>,
    dev: Option<String>,
}
impl ServerRepoConfig {
    pub(crate) fn repo(&self) -> RepoPath {
        RepoPath::new(self.repo.clone())
    }

    pub(crate) fn branch(&self) -> BranchName {
        BranchName::new(&self.branch)
    }

    #[must_use]
    pub fn gitdir(&self) -> Option<GitDir> {
        self.gitdir
            .clone()
            // Provenance is external as the gitdir is only used to specify non-internal paths
            .map(|dir| GitDir::new(dir, StoragePathType::External))
    }

    /// Returns a `RepoConfig` from the server configuration if ALL THREE branches were provided
    #[must_use]
    pub fn repo_config(&self) -> Option<RepoConfig> {
        match (&self.main, &self.next, &self.dev) {
            (Some(main), Some(next), Some(dev)) => Some(RepoConfig::new(
                RepoBranches::new(s!(main), s!(next), s!(dev)),
                RepoConfigSource::Server,
            )),
            _ => None,
        }
    }
}
